==> owncloud-10.0.7.tgz: owncloud/core/l10n/ro.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Te rugăm să alegi un fișier.",
    "File is too big" : "Fișierul este prea mare",
    "Invalid file provided" : "Numele fișierului pe care l-ai oferit este invalid",
    "No image or file provided" : "Nu a fost furnizat vreo imagine sau fișier",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "An error occurred. Please contact your admin." : "A apărut o eroare. Te rugăm să contactezi administratorul.",
    "No temporary profile picture available, try again" : "Nu este disponibilă nicio imagine temporară a profilului, încearcă din nou",
    "Crop is not square" : "Selecția nu este pătrată",
    "Couldn't reset password because the token is invalid" : "Parola nu a putut fi resetată deoarece token-ul este invalid",
    "Couldn't reset password because the token is expired" : "Parola nu a putut fi resetată deoarece token-ul a expirat",
    "%s password reset" : "%s resetare parola",
    "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
    "Couldn't send mail to following users: %s " : "Nu s-a putut trimite mesajul către următorii utilizatori: %s",
    "Preparing update" : "Se pregătește actualizarea",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Alerte reparare:",
    "Repair error: " : "Eroare de reparare:",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Se verifică tabela %s",
    "Turned on maintenance mode" : "Modul mentenanță a fost activat",
    "Turned off maintenance mode" : "Modul mentenanță a fost dezactivat",
    "Maintenance mode is kept active" : "Modul de mentenanță este menținut activ",
    "Updating database schema" : "Se actualizează schema bazei de date",
    "Updated database" : "Bază de date actualizată",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Se verifică dacă schema bazei de date poate fi actualizată (această verificare poate lua mult timp în funcție de mărimea bazei de date)",
    "Checking updates of apps" : "Se verifică actualizările aplicațiilor",
    "Updated \"%s\" to %s" : "\"%s\" a fost actualizat până la %s",
    "Set log level to debug" : "Setează nivelul de logare la \"debug\"",
    "Reset log level" : "Resetează nivelul de logare",
    "Starting code integrity check" : "Începe verificarea integrității codului",
    "Finished code integrity check" : "Verificarea integrității codului a fost finalizată",
    "%s (3rdparty)" : "%s (terță parte)",
    "%s (incompatible)" : "%s (incompatibil)",
    "Following apps have been disabled: %s" : "Următoarele aplicații au fost dezactivate: %s",
    "Already up to date" : "Deja actualizat",
    "Sunday" : "Duminică",
    "Monday" : "Luni",
    "Tuesday" : "Marți",
    "Wednesday" : "Miercuri",
    "Thursday" : "Joi",
    "Friday" : "Vineri",
    "Saturday" : "Sâmbătă",
    "Sun." : "Dum.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Joi",
    "Fri." : "Vin.",
    "Sat." : "Sâm.",
    "Su" : "Du",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Jo",
    "Fr" : "Vi",
    "Sa" : "Sâ",
    "January" : "Ianuarie",
    "February" : "Februarie",
    "March" : "Martie",
    "April" : "Aprilie",
    "May" : "Mai",
    "June" : "Iunie",
    "July" : "Iulie",
    "August" : "August",
    "September" : "Septembrie",
    "October" : "Octombrie",
    "November" : "Noiembrie",
    "December" : "Decembrie",
    "Jan." : "Ian.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Iun.",
    "Jul." : "Iul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Noi.",
    "Dec." : "Dec.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Au apărut probleme la verificarea integrității codului. Mai multe informații…</a>",
    "Settings" : "Setări",
    "Problem loading page, reloading in 5 seconds" : "A apărut o problemă la încărcarea paginii, se reîncearcă în 5 secunde",
    "Saving..." : "Se salvează...",
    "Dismiss" : "Înlătură",
    "seconds ago" : "secunde în urmă",
    "I know what I'm doing" : "Eu știu ce fac",
    "Password can not be changed. Please contact your administrator." : "Parola nu poate fi modificată. Vă rugăm să contactați administratorul dvs.",
    "No" : "Nu",
    "Yes" : "Da",
    "Choose" : "Alege",
    "Error loading file picker template: {error}" : "Eroare la încărcarea șablonului selectorului de fișiere: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Eroare la încărcarea şablonului de mesaje: {error}",
    "read-only" : "doar citire",
    "_{count} file conflict_::_{count} file conflicts_" : ["Un conflict de fişiere","{count} conflicte de fişiere","{count} conflicte de fişiere"],
    "One file conflict" : "Un conflict de fișier",
    "New Files" : "Fișiere noi",
    "Already existing files" : "Fișiere deja existente",
    "Which files do you want to keep?" : "Ce fișiere vrei să păstrezi?",
    "If you select both versions, the copied file will have a number added to its name." : "Dacă alegi ambele versiuni, fișierul copiat va avea un număr atașat la denumirea sa.",
    "Cancel" : "Anulare",
    "Continue" : "Continuă",
    "(all selected)" : "(toate selectate)",
    "({count} selected)" : "({count} selectate)",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Error occurred while checking server setup" : "A apărut o eroare la verificarea configurației serverului",
    "Shared" : "Partajat",
    "Shared with {recipients}" : "Partajat cu {recipients}",
    "Error" : "Eroare",
    "Error while sharing" : "Eroare la partajare",
    "Error while unsharing" : "Eroare la anularea partajării",
    "The public link will expire no later than {days} days after it is created" : "Legătura publică va expira nu mai târziu de {days} zile de la ziua creării",
    "Set expiration date" : "Specifică data expirării",
    "Expiration" : "Expira",
    "Expiration date" : "Data expirării",
    "Link" : "Legătură",
    "Edit" : "Editează",
    "Remove" : "Șterge",
    "Choose a password for the public link" : "Alege o parolă pentru acest link public",
    "Filename" : "Nume fișier",
    "Password" : "Parolă",
    "Name" : "Nume",
    "Allow editing" : "Permite editarea",
    "Save" : "Salvează",
    "Error while sending notification" : "Eroare la trimiterea notificării",
    "Sending ..." : "Se expediază...",
    "Email sent" : "Mesajul a fost expediat",
    "Email link to person" : "Expediază legătura prin poșta electronică",
    "Send link via email" : "Trimite link via email",
    "Shared with you and the group {group} by {owner}" : "Distribuie cu tine si grupul {group} de {owner}",
    "Shared with you by {owner}" : "Distribuie cu tine de {owner}",
    "group" : "grup",
    "remote" : "de la distanță",
    "notify by email" : "notifică prin email",
    "Unshare" : "Anulare partajare",
    "can share" : "se poate partaja",
    "can edit" : "poate edita",
    "create" : "creare",
    "change" : "modifică",
    "delete" : "ștergere",
    "access control" : "control acces",
    "Could not unshare" : "Nu s-a putut elimina partajarea",
    "Share details could not be loaded for this item." : "Nu s-au putut încărca detaliile de partajare pentru acest element.",
    "No users or groups found for {search}" : "Nu au fost găsiți utilizatori sau grupuri pentru {search}",
    "No users found for {search}" : "Nu au fost găsiți utilizatori pentru {search}",
    "An error occurred. Please try again" : "A apărut o eroare. Încearcă din nou",
    "Share" : "Partajează",
    "Resharing is not allowed" : "Repartajarea nu este permisă",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partajează cu persoane din alte instanțe ownCloud folosind sintaxa nume_utilizator@exemplu.com/owncloud",
    "Share with users…" : "Partajează cu utilizatori...",
    "Share with users or groups…" : "Partajează cu utilizatori sau grupuri...",
    "Error removing share" : "Eroare la înlăturarea elementului partajat",
    "Warning" : "Atenție",
    "Non-existing tag #{tag}" : "Etichetă inexistentă #{tag}",
    "restricted" : "restricționat",
    "invisible" : "invizibil",
    "Delete" : "Șterge",
    "Rename" : "Redenumește",
    "Collaborative tags" : "Etichete colaborative",
    "The object type is not specified." : "Tipul obiectului nu este specificat.",
    "Enter new" : "Introducere nou",
    "Add" : "Adaugă",
    "Edit tags" : "Editează etichete",
    "No tags selected for deletion." : "Nu au fost selectate etichete pentru ștergere.",
    "unknown text" : "text necunoscut",
    "Hello world!" : "Hello world!",
    "sunny" : "însorit",
    "Hello {name}" : "Salut {name}",
    "new" : "nou",
    "_download %n file_::_download %n files_" : ["descarcă %n fișier","descarcă %n fișiere","descarcă %n fișiere"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Actualizarea este în progres, părăsirea acestei pagini ar putea duce la întreruperea procesului în unele medii.",
    "Updating to {version}" : "Actualizare la {version}",
    "An error occurred." : "A apărut o eroare.",
    "Please reload the page." : "Te rugăm să reîncarci pagina.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Actualizarea a eșuat! Raportați problema către <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">comunitatea ownCloud</a>.",
    "The update was successful. There were warnings." : "Actualizarea nu a avut loc cu succes. Au existat avertismente.",
    "The update was successful. Redirecting you to ownCloud now." : "Actualizare reușită. Ești redirecționat către ownCloud.",
    "Searching other places" : "Se caută în alte locuri",
    "No search results in other folders" : "Nu există rezultate ale căutării în alte directoare",
    "Personal" : "Personal",
    "Users" : "Utilizatori",
    "Apps" : "Aplicații",
    "Admin" : "Administrator",
    "Help" : "Ajutor",
    "Access forbidden" : "Acces restricționat",
    "File not found" : "Fișierul nu a fost găsit",
    "The specified document has not been found on the server." : "Documentul specificat nu a fost găsit pe server.",
    "You can click here to return to %s." : "Poți da click aici pentru a te întoarce la %s.",
    "The share will expire on %s." : "Partajarea va expira în data de %s.",
    "Cheers!" : "Noroc!",
    "Internal Server Error" : "Eroare internă a serverului",
    "The server encountered an internal error and was unable to complete your request." : "Serverul a întâmpinat o eroare și nu îți poate îndeplini cererea.",
    "Technical details" : "Detalii tehnice",
    "Type: %s" : "Tip: %s",
    "Code: %s" : "Cod: %s",
    "Message: %s" : "Mesaj: %s",
    "File: %s" : "Fișier: %s",
    "Create an <strong>admin account</strong>" : "Crează un <strong>cont de administrator</strong>",
    "Username" : "Nume utilizator",
    "Storage & database" : "Stocare și baza de date",
    "Data folder" : "Director date",
    "Configure the database" : "Configurează baza de date",
    "Only %s is available." : "Doar %s este disponibil.",
    "Database user" : "Utilizatorul bazei de date",
    "Database password" : "Parola bazei de date",
    "Database name" : "Numele bazei de date",
    "Database tablespace" : "Tabela de spațiu a bazei de date",
    "Database host" : "Bază date",
    "Performance warning" : "Alertă de performanță",
    "SQLite will be used as database." : "SQLite va fi folosit ca bază de date.",
    "For larger installations we recommend to choose a different database backend." : "Pentru instalări mai mari recomandăm folosirea altei baze de date ca backend.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "În special atunci când este folosit clientul desktop pentru sincronizarea fișierelor, utilizarea SQLite este nerecomandată.",
    "Finish setup" : "Finalizează instalarea",
    "Finishing …" : "Se finalizează...",
    "Need help?" : "Ai nevoie de ajutor?",
    "See the documentation" : "Vezi documentația",
    "Log out" : "Ieșire",
    "Search" : "Căutare",
    "Please contact your administrator." : "Contactează-ți administratorul.",
    "An internal error occurred." : "A apărut o eroare internă.",
    "Please try again or contact your administrator." : "Încearcă din nou sau contactează-ți administratorul.",
    "Username or email" : "Nume de utilizator sau adresă email",
    "Log in" : "Autentificare",
    "Wrong password. Reset it?" : "Parolă greșită. O resetezi?",
    "Wrong password." : "Parolă greșită.",
    "Stay logged in" : "Rămâi autentificat",
    "Alternative Logins" : "Conectări alternative",
    "Use the following link to reset your password: {link}" : "Folosește următorul link pentru a reseta parola: {link}",
    "New password" : "Noua parolă",
    "New Password" : "Noua parolă",
    "Reset password" : "Resetează parola",
    "This ownCloud instance is currently in single user mode." : "Această instanță ownCloud este momentan în modul de utilizare de către un singur utilizator.",
    "This means only administrators can use the instance." : "Asta înseamnă că doar administratorii pot folosi instanța.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactează-ți administratorul de sistem dacă acest mesaj persistă sau a apărut neașteptat.",
    "Thank you for your patience." : "Îți mulțumim pentru răbdare.",
    "Two-step verification" : "Verificare în doi pași",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "A fost activată securitatea sporită pentru contul tău. Te rugăm să te autentifici folosind un al doilea factor.",
    "Cancel login" : "Anulează autentificarea",
    "Please authenticate using the selected factor." : "Autentifică-te folosind factorul ales.",
    "You are accessing the server from an untrusted domain." : "Accesezi serverul dintr-un domeniu care nu a fost configurat ca fiind de încredere.",
    "Add \"%s\" as trusted domain" : "Adaugă \"%s\" ca domeniu de încredere",
    "App update required" : "E necesară o actualizare a aplicației",
    "%s will be updated to version %s" : "%s va fi actualizat la versiunea %s",
    "These apps will be updated:" : "Aceste aplicații vor fi actualizate:",
    "The theme %s has been disabled." : "Tema %s a fost dezactivată.",
    "Start update" : "Începe actualizarea",
    "Detailed logs" : "Loguri detaliate",
    "Update needed" : "E necesară actualizarea",
    "Please use the command line updater because you have a big instance." : "Folosește actualizarea din linia de comandă deoarece ai o instanță mare.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Instanța %s este acum în modul de mentenanță, ceea ce ar putea dura o vreme.",
    "This page will refresh itself when the %s instance is available again." : "Această pagină se va reîmprospăta atunci când %s instance e disponibil din nou."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> owncloud-10.0.10.tgz: owncloud/core/l10n/ro.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Te rugăm să alegi un fișier.",
    "File is too big" : "Fișierul este prea mare",
    "Invalid file provided" : "Numele fișierului pe care l-ai oferit este invalid",
    "No image or file provided" : "Nu a fost furnizat vreo imagine sau fișier",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "An error occurred. Please contact your admin." : "A apărut o eroare. Te rugăm să contactezi administratorul.",
    "No temporary profile picture available, try again" : "Nu este disponibilă nicio imagine temporară a profilului, încearcă din nou",
    "Crop is not square" : "Selecția nu este pătrată",
    "Couldn't reset password because the token is invalid" : "Parola nu a putut fi resetată deoarece token-ul este invalid",
    "Couldn't reset password because the token is expired" : "Parola nu a putut fi resetată deoarece token-ul a expirat",
    "%s password reset" : "%s resetare parola",
    "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
    "Couldn't send mail to following users: %s " : "Nu s-a putut trimite mesajul către următorii utilizatori: %s",
    "Preparing update" : "Se pregătește actualizarea",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Alerte reparare:",
    "Repair error: " : "Eroare de reparare:",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Se verifică tabela %s",
    "Turned on maintenance mode" : "Modul mentenanță a fost activat",
    "Turned off maintenance mode" : "Modul mentenanță a fost dezactivat",
    "Maintenance mode is kept active" : "Modul de mentenanță este menținut activ",
    "Updating database schema" : "Se actualizează schema bazei de date",
    "Updated database" : "Bază de date actualizată",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Se verifică dacă schema bazei de date poate fi actualizată (această verificare poate lua mult timp în funcție de mărimea bazei de date)",
    "Checking updates of apps" : "Se verifică actualizările aplicațiilor",
    "Updated \"%s\" to %s" : "\"%s\" a fost actualizat până la %s",
    "Set log level to debug" : "Setează nivelul de logare la \"debug\"",
    "Reset log level" : "Resetează nivelul de logare",
    "Starting code integrity check" : "Începe verificarea integrității codului",
    "Finished code integrity check" : "Verificarea integrității codului a fost finalizată",
    "%s (3rdparty)" : "%s (terță parte)",
    "%s (incompatible)" : "%s (incompatibil)",
    "Following apps have been disabled: %s" : "Următoarele aplicații au fost dezactivate: %s",
    "Already up to date" : "Deja actualizat",
    "Sunday" : "Duminică",
    "Monday" : "Luni",
    "Tuesday" : "Marți",
    "Wednesday" : "Miercuri",
    "Thursday" : "Joi",
    "Friday" : "Vineri",
    "Saturday" : "Sâmbătă",
    "Sun." : "Dum.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Joi",
    "Fri." : "Vin.",
    "Sat." : "Sâm.",
    "Su" : "Du",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Jo",
    "Fr" : "Vi",
    "Sa" : "Sâ",
    "January" : "Ianuarie",
    "February" : "Februarie",
    "March" : "Martie",
    "April" : "Aprilie",
    "May" : "Mai",
    "June" : "Iunie",
    "July" : "Iulie",
    "August" : "August",
    "September" : "Septembrie",
    "October" : "Octombrie",
    "November" : "Noiembrie",
    "December" : "Decembrie",
    "Jan." : "Ian.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Iun.",
    "Jul." : "Iul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Noi.",
    "Dec." : "Dec.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Au apărut probleme la verificarea integrității codului. Mai multe informații…</a>",
    "Settings" : "Setări",
    "Problem loading page, reloading in 5 seconds" : "A apărut o problemă la încărcarea paginii, se reîncearcă în 5 secunde",
    "Saving..." : "Se salvează...",
    "Dismiss" : "Înlătură",
    "seconds ago" : "secunde în urmă",
    "I know what I'm doing" : "Eu știu ce fac",
    "Password can not be changed. Please contact your administrator." : "Parola nu poate fi modificată. Vă rugăm să contactați administratorul dvs.",
    "No" : "Nu",
    "Yes" : "Da",
    "Choose" : "Alege",
    "Error loading file picker template: {error}" : "Eroare la încărcarea șablonului selectorului de fișiere: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Eroare la încărcarea şablonului de mesaje: {error}",
    "read-only" : "doar citire",
    "_{count} file conflict_::_{count} file conflicts_" : ["Un conflict de fişiere","{count} conflicte de fişiere","{count} conflicte de fişiere"],
    "One file conflict" : "Un conflict de fișier",
    "New Files" : "Fișiere noi",
    "Already existing files" : "Fișiere deja existente",
    "Which files do you want to keep?" : "Ce fișiere vrei să păstrezi?",
    "If you select both versions, the copied file will have a number added to its name." : "Dacă alegi ambele versiuni, fișierul copiat va avea un număr atașat la denumirea sa.",
    "Cancel" : "Anulare",
    "Continue" : "Continuă",
    "(all selected)" : "(toate selectate)",
    "({count} selected)" : "({count} selectate)",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Error occurred while checking server setup" : "A apărut o eroare la verificarea configurației serverului",
    "Shared" : "Partajat",
    "Shared with {recipients}" : "Partajat cu {recipients}",
    "Error" : "Eroare",
    "Error while sharing" : "Eroare la partajare",
    "Error while unsharing" : "Eroare la anularea partajării",
    "The public link will expire no later than {days} days after it is created" : "Legătura publică va expira nu mai târziu de {days} zile de la ziua creării",
    "Set expiration date" : "Specifică data expirării",
    "Expiration" : "Expira",
    "Expiration date" : "Data expirării",
    "Link" : "Legătură",
    "Edit" : "Editează",
    "Remove" : "Șterge",
    "Choose a password for the public link" : "Alege o parolă pentru acest link public",
    "Filename" : "Nume fișier",
    "Password" : "Parolă",
    "Name" : "Nume",
    "Allow editing" : "Permite editarea",
    "Save" : "Salvează",
    "Error while sending notification" : "Eroare la trimiterea notificării",
    "Sending ..." : "Se expediază...",
    "Email sent" : "Mesajul a fost expediat",
    "Email link to person" : "Expediază legătura prin poșta electronică",
    "Send link via email" : "Trimite link via email",
    "Shared with you and the group {group} by {owner}" : "Distribuie cu tine si grupul {group} de {owner}",
    "Shared with you by {owner}" : "Distribuie cu tine de {owner}",
    "group" : "grup",
    "remote" : "de la distanță",
    "notify by email" : "notifică prin email",
    "Unshare" : "Anulare partajare",
    "can share" : "se poate partaja",
    "can edit" : "poate edita",
    "create" : "creare",
    "change" : "modifică",
    "delete" : "ștergere",
    "access control" : "control acces",
    "Could not unshare" : "Nu s-a putut elimina partajarea",
    "Share details could not be loaded for this item." : "Nu s-au putut încărca detaliile de partajare pentru acest element.",
    "No users or groups found for {search}" : "Nu au fost găsiți utilizatori sau grupuri pentru {search}",
    "No users found for {search}" : "Nu au fost găsiți utilizatori pentru {search}",
    "An error occurred. Please try again" : "A apărut o eroare. Încearcă din nou",
    "Share" : "Partajează",
    "Resharing is not allowed" : "Repartajarea nu este permisă",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partajează cu persoane din alte instanțe ownCloud folosind sintaxa nume_utilizator@exemplu.com/owncloud",
    "Share with users…" : "Partajează cu utilizatori...",
    "Share with users or groups…" : "Partajează cu utilizatori sau grupuri...",
    "Error removing share" : "Eroare la înlăturarea elementului partajat",
    "Warning" : "Atenție",
    "Non-existing tag #{tag}" : "Etichetă inexistentă #{tag}",
    "restricted" : "restricționat",
    "invisible" : "invizibil",
    "Delete" : "Șterge",
    "Rename" : "Redenumește",
    "Collaborative tags" : "Etichete colaborative",
    "The object type is not specified." : "Tipul obiectului nu este specificat.",
    "Enter new" : "Introducere nou",
    "Add" : "Adaugă",
    "Edit tags" : "Editează etichete",
    "No tags selected for deletion." : "Nu au fost selectate etichete pentru ștergere.",
    "unknown text" : "text necunoscut",
    "Hello world!" : "Hello world!",
    "sunny" : "însorit",
    "Hello {name}" : "Salut {name}",
    "new" : "nou",
    "_download %n file_::_download %n files_" : ["descarcă %n fișier","descarcă %n fișiere","descarcă %n fișiere"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Actualizarea este în progres, părăsirea acestei pagini ar putea duce la întreruperea procesului în unele medii.",
    "Updating to {version}" : "Actualizare la {version}",
    "An error occurred." : "A apărut o eroare.",
    "Please reload the page." : "Te rugăm să reîncarci pagina.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Actualizarea a eșuat! Raportați problema către <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">comunitatea ownCloud</a>.",
    "The update was successful. There were warnings." : "Actualizarea nu a avut loc cu succes. Au existat avertismente.",
    "The update was successful. Redirecting you to ownCloud now." : "Actualizare reușită. Ești redirecționat către ownCloud.",
    "Searching other places" : "Se caută în alte locuri",
    "No search results in other folders" : "Nu există rezultate ale căutării în alte directoare",
    "Personal" : "Personal",
    "Users" : "Utilizatori",
    "Apps" : "Aplicații",
    "Admin" : "Administrator",
    "Help" : "Ajutor",
    "Access forbidden" : "Acces restricționat",
    "File not found" : "Fișierul nu a fost găsit",
    "The specified document has not been found on the server." : "Documentul specificat nu a fost găsit pe server.",
    "You can click here to return to %s." : "Poți da click aici pentru a te întoarce la %s.",
    "The share will expire on %s." : "Partajarea va expira în data de %s.",
    "Cheers!" : "Noroc!",
    "Internal Server Error" : "Eroare internă a serverului",
    "The server encountered an internal error and was unable to complete your request." : "Serverul a întâmpinat o eroare și nu îți poate îndeplini cererea.",
    "Technical details" : "Detalii tehnice",
    "Type: %s" : "Tip: %s",
    "Code: %s" : "Cod: %s",
    "Message: %s" : "Mesaj: %s",
    "File: %s" : "Fișier: %s",
    "Create an <strong>admin account</strong>" : "Crează un <strong>cont de administrator</strong>",
    "Username" : "Nume utilizator",
    "Storage & database" : "Stocare și baza de date",
    "Data folder" : "Director date",
    "Configure the database" : "Configurează baza de date",
    "Only %s is available." : "Doar %s este disponibil.",
    "Database user" : "Utilizatorul bazei de date",
    "Database password" : "Parola bazei de date",
    "Database name" : "Numele bazei de date",
    "Database tablespace" : "Tabela de spațiu a bazei de date",
    "Database host" : "Bază date",
    "Performance warning" : "Alertă de performanță",
    "SQLite will be used as database." : "SQLite va fi folosit ca bază de date.",
    "For larger installations we recommend to choose a different database backend." : "Pentru instalări mai mari recomandăm folosirea altei baze de date ca backend.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "În special atunci când este folosit clientul desktop pentru sincronizarea fișierelor, utilizarea SQLite este nerecomandată.",
    "Finish setup" : "Finalizează instalarea",
    "Finishing …" : "Se finalizează...",
    "Need help?" : "Ai nevoie de ajutor?",
    "See the documentation" : "Vezi documentația",
    "Log out" : "Ieșire",
    "Search" : "Căutare",
    "Please contact your administrator." : "Contactează-ți administratorul.",
    "An internal error occurred." : "A apărut o eroare internă.",
    "Please try again or contact your administrator." : "Încearcă din nou sau contactează-ți administratorul.",
    "Username or email" : "Nume de utilizator sau adresă email",
    "Log in" : "Autentificare",
    "Wrong password. Reset it?" : "Parolă greșită. O resetezi?",
    "Wrong password." : "Parolă greșită.",
    "Stay logged in" : "Rămâi autentificat",
    "Alternative Logins" : "Conectări alternative",
    "Use the following link to reset your password: {link}" : "Folosește următorul link pentru a reseta parola: {link}",
    "New password" : "Noua parolă",
    "New Password" : "Noua parolă",
    "Reset password" : "Resetează parola",
    "This ownCloud instance is currently in single user mode." : "Această instanță ownCloud este momentan în modul de utilizare de către un singur utilizator.",
    "This means only administrators can use the instance." : "Asta înseamnă că doar administratorii pot folosi instanța.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactează-ți administratorul de sistem dacă acest mesaj persistă sau a apărut neașteptat.",
    "Thank you for your patience." : "Îți mulțumim pentru răbdare.",
    "Two-step verification" : "Verificare în doi pași",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "A fost activată securitatea sporită pentru contul tău. Te rugăm să te autentifici folosind un al doilea factor.",
    "Cancel login" : "Anulează autentificarea",
    "Please authenticate using the selected factor." : "Autentifică-te folosind factorul ales.",
    "You are accessing the server from an untrusted domain." : "Accesezi serverul dintr-un domeniu care nu a fost configurat ca fiind de încredere.",
    "Add \"%s\" as trusted domain" : "Adaugă \"%s\" ca domeniu de încredere",
    "App update required" : "E necesară o actualizare a aplicației",
    "%s will be updated to version %s" : "%s va fi actualizat la versiunea %s",
    "These apps will be updated:" : "Aceste aplicații vor fi actualizate:",
    "The theme %s has been disabled." : "Tema %s a fost dezactivată.",
    "Start update" : "Începe actualizarea",
    "Detailed logs" : "Loguri detaliate",
    "Update needed" : "E necesară actualizarea",
    "Please use the command line updater because you have a big instance." : "Folosește actualizarea din linia de comandă deoarece ai o instanță mare.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Instanța %s este acum în modul de mentenanță, ceea ce ar putea dura o vreme.",
    "This page will refresh itself when the %s instance is available again." : "Această pagină se va reîmprospăta atunci când %s instance e disponibil din nou.",
    "Remove link" : "Șterge legătura",
    "Copy to clipboard" : "Copiază în clipboard",
    "Anyone with the link has access to the file/folder" : "Oricine are legătura are acces la fișier/dosar",
    "Menu" : "Meniu",
    "Link name" : "Numele legăturii",
    "%s password changed successfully" : "parola %s a fost schimbată cu succes",
    "Imprint" : "Imprint"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
